@@ -19,6 +19,7 @@ pub fn object_super() -> impl Fold + VisitMut {
 
 impl VisitMut for ObjectSuper {
     noop_visit_mut_type!();
+
     fn visit_mut_module_items(&mut self, n: &mut Vec<ModuleItem>) {
         n.visit_mut_children_with(self);
         if !self.extra_vars.is_empty() {
@@ -43,6 +44,7 @@ impl VisitMut for ObjectSuper {
             );
         }
     }
+
     fn visit_mut_stmts(&mut self, stmts: &mut Vec<Stmt>) {
         stmts.visit_mut_children_with(self);
         if !self.extra_vars.is_empty() {
@@ -153,6 +155,7 @@ impl SuperReplacer {
             ident
         }
     }
+
     fn get_proto(&mut self) -> ExprOrSpread {
         Expr::Call(CallExpr {
             span: DUMMY_SP,
@@ -178,6 +181,7 @@ impl SuperReplacer {
             SuperProp::Computed(ComputedPropName { expr, .. }) => expr,
         }
     }
+
     /// # In
     /// ```js
     /// super.foo(a)
@@ -334,6 +338,7 @@ impl SuperReplacer {
             type_args: Default::default(),
         })
     }
+
     fn to_bin_expr(left: Box<Expr>, op: AssignOp, rhs: Box<Expr>) -> BinExpr {
         BinExpr {
             span: DUMMY_SP,
@@ -342,6 +347,7 @@ impl SuperReplacer {
             right: rhs,
         }
     }
+
     fn call_set_helper(
         &mut self,
         super_token: Span,
@@ -362,6 +368,7 @@ impl SuperReplacer {
             type_args: Default::default(),
         })
     }
+
     fn super_to_set_call(
         &mut self,
         super_token: Span,
@@ -461,11 +468,13 @@ impl SuperReplacer {
 }
 #[cfg(test)]
 mod tests {
-    use super::*;
-    use crate::es2015::{function_name, shorthand_property::shorthand};
     use swc_common::{chain, Mark};
+    use swc_ecma_parser::{EsConfig, Syntax};
     use swc_ecma_transforms_base::resolver::resolver_with_mark;
     use swc_ecma_transforms_testing::test;
+
+    use super::*;
+    use crate::es2015::{function_name, shorthand_property::shorthand};
     test!(
         ::swc_ecma_parser::Syntax::default(),
         |_| {
@@ -575,7 +584,10 @@ mod tests {
     };"#
     );
     test!(
-        ::swc_ecma_parser::Syntax::default(),
+        Syntax::Es(EsConfig {
+            allow_super_outside_method: true,
+            ..Default::default()
+        }),
         |_| {
             let top_level_mark = Mark::fresh(Mark::root());
             chain!(
